/*
 * Copyright (C) 2004  Heinz Mauelshagen, Red Hat GmbH. All rights reserved.
 *
 * See file LICENSE at the top of this source tree for license information.
 */

#include "internal.h"

/* Library initialization. */
int libdmraid_init(struct lib_context **lc, int argc, char **argv)
{
	if (!(*lc = alloc_lib_context(argv)))
		return 0;

	init_locking(*lc);
	sysfs_workaround(*lc);	/* FIXME: do we need this forever ? */

	return register_format_handlers(*lc);
}

/* Library exit processing. */
void libdmraid_exit(struct lib_context *lc)
{
	free_raid_set(lc, NULL);	/* Free all RAID sets. */
	free_raid_dev(lc, NULL);	/* Free all RAID devices. */
	free_dev_info(lc, NULL);	/* Free all disk infos. */
	unregister_format_handlers(lc);	/* Unregister all format handlers. */
	free_lib_context(lc);		/* Release library context. */
}

/* Return library date (ASCII). */
const char *libdmraid_date(struct lib_context *lc)
{
	return lc->version.date;
}

/* Return library version (ASCII). */
const char *libdmraid_version(struct lib_context *lc)
{
	return lc->version.text;
}
