/*
 * Copyright (C) 2004  Heinz Mauelshagen, Red Hat GmbH. All rights reserved.
 *
 * See file LICENSE at the top of this source tree for license information.
 */

#include <stdarg.h>
#include "internal.h"
#include "version.h"

/* Options access functions. */
static inline int lc_opt_ok(enum lc_options o)
{
	return o < LC_OPTIONS_SIZE;
}

int lc_opt(struct lib_context *lc, enum lc_options o)
{
	return lc_opt_ok(o) ? lc->opts[o] : 0;
}

static int _inc_opt(struct lib_context *lc, int o)
{
	return lc->opts[o] < UCHAR_MAX ? ++lc->opts[o] : lc->opts[o];
}

int lc_inc_opt(struct lib_context *lc, int o)
{
	return lc_opt_ok(o) ? _inc_opt(lc, o) : 0;
}

struct list_head *lc_list(struct lib_context *lc, int l)
{
	return l < ARRAY_SIZE(lc->lists) ? &lc->lists[l] : NULL;
}

/*
 * Library context initialization functions.
 */
static void init_cmd(struct lib_context *lc, char **argv)
{
	lc->cmd = get_basename(lc, argv[0]);
}

/* FIXME: add lib flavour info (e.g., DEBUG). */
static void init_version(struct lib_context *lc)
{
	lc->version.text	= DMRAID_LIB_VERSION;
	lc->version.date	= DMRAID_LIB_DATE;
	lc->version.v.major	= DMRAID_LIB_MAJOR_VERSION;
	lc->version.v.minor	= DMRAID_LIB_MINOR_VERSION;
	lc->version.v.sub_minor	= DMRAID_LIB_SUBMINOR_VERSION;
	lc->version.v.suffix	= DMRAID_LIB_VERSION_SUFFIX;
}

static void init_mode(struct lib_context *lc)
{
	lc->mode = 0600;
}

static void init_lists(struct lib_context *lc)
{
	unsigned int i;

	for (i = 0; i < LC_LISTS_SIZE; i++)
		INIT_LIST_HEAD(&lc->lists[i]);
}

static void init_paths(struct lib_context *lc)
{
	lc->path.error = "/dev/zero";
}

void free_lib_context(struct lib_context *lc)
{
	dbg_free(lc);
}

struct lib_context *alloc_lib_context(char **argv)
{
	struct lib_context *lc = NULL;

	if ((lc = dbg_malloc(sizeof(*lc)))) {
		init_cmd(lc, argv);
		init_version(lc);
		init_mode(lc);
		init_lists(lc);
		init_paths(lc);
#ifdef	DEBUG_MALLOC
		/*
		 * Set DEBUG flag in case of memory debugging so that we
		 * see messages even before the command line gets parsed.
		 */
		lc_inc_opt(lc, LC_DEBUG);
#endif

	} else
		fprintf(stderr, "allocating library context\n");

	return lc;
}

